diff -rubw ./FL/Fl_Input_Choice.H wip_2752/FL/Fl_Input_Choice.H
--- ./FL/Fl_Input_Choice.H	2017-03-12 22:11:31.215017000 +0100
+++ wip_2752/FL/Fl_Input_Choice.H	2017-03-12 22:17:09.675017000 +0100
@@ -54,8 +54,18 @@
   // Private class to handle slightly 'special' behavior of menu button
   class InputMenuButton : public Fl_Menu_Button {
     void draw();
+
+  protected:
+    static const int FLAG_EX_ARROW_SHORTCUT=1;  // allow arrow down to open menu
+    int flags_ex_;
+
   public:
     InputMenuButton(int X, int Y, int W, int H, const char *L=0);
+    int handle(int event);
+
+    void enable_arrow_shortcut(void) { flags_ex_ |= FLAG_EX_ARROW_SHORTCUT; };
+    void disable_arrow_shortcut(void) { flags_ex_ &= ~FLAG_EX_ARROW_SHORTCUT; };
+    bool using_arrow_shortcut(void) { return (flags_ex_ & FLAG_EX_ARROW_SHORTCUT)!=0; };
   };
 
   Fl_Input *inp_;
diff -rubw ./src/Fl_Input_Choice.cxx wip_2752/src/Fl_Input_Choice.cxx
--- ./src/Fl_Input_Choice.cxx	2017-03-12 22:35:13.323017000 +0100
+++ wip_2752/src/Fl_Input_Choice.cxx	2017-03-12 22:27:57.771017000 +0100
@@ -95,9 +95,25 @@
 Fl_Input_Choice::InputMenuButton::InputMenuButton(int x,int y,int w,int h,const char*l)
                                  :Fl_Menu_Button(x,y,w,h,l)
 {
+  flags_ex_ = 0;
   box(FL_UP_BOX);
 }
 
+/** Handle down arrow to open button */
+
+int Fl_Input_Choice::InputMenuButton::handle(int event)
+{
+  if (using_arrow_shortcut()) {
+    // captures all forms of down arrow to open menu.
+    if (event==FL_KEYBOARD && Fl::focus()==this && Fl::event_key()==FL_Down) {
+      popup();
+      return 1;
+    }
+  }
+
+  return Fl_Menu_Button::handle(event);
+}
+
 /** Draws the private menu button. */
 
 void Fl_Input_Choice::InputMenuButton::draw() {
@@ -214,6 +230,28 @@
   Fl_Widget::clear_changed();
 }
 
+/** Handle down arrow to open menu.
+
+    \param[in]	event	FLTK event (handles FL_KEYBOARD only)
+*/
+
+int Fl_Input_Choice::handle(int event)
+{
+  // this captures Alt-Down arrow when input field has keyboard focus
+  // because a normal down arrow is already eaten by the Fl_Input
+  // object (receives handle first when it has focus).  If you want
+  // the down arrow to work too, you'd need to subclass Fl_Input
+  // and override handle()
+
+  if (using_arrow_shortcut()) {
+    if (event==FL_KEYBOARD && Fl::focus()==inp_ && Fl::event_key()==FL_Down) {
+      menu_->popup();
+      return 1;
+    }
+  }
+  return Fl_Group::handle(event);
+}
+
 
 //
 // End of "$Id$".
